import type { PathOrFileDescriptor } from 'fs-extra';
import type { NodePlopAPI } from 'node-plop';
import { ActionConfig } from 'node-plop';
export declare enum FileSystemActionType {
    createDirectory = "Create directory",
    createPath = "Create path",
    replaceContent = "Replace content"
}
export declare namespace FileSystemActionConfig {
    interface CreateDirectory extends ActionConfig {
        get directory(): string;
    }
    interface CreatePath extends ActionConfig {
        get paths(): string[];
        get answerKey(): string;
    }
    interface ReplaceContent extends ActionConfig {
        get filePath(): string;
        get searchRegex(): RegExp;
        get replaceValue(): string;
    }
}
export declare namespace FileSystemActions {
    const writeFile: (file: PathOrFileDescriptor, data: string) => void;
    const readFile: (file: PathOrFileDescriptor) => string;
    const createDirectory: (directory: string) => void;
    const copyDirectoryContentsTo: (source: string, destination: string) => Promise<void>;
    const createPath: (...paths: string[]) => string;
    const replaceContent: (filePath: string, searchRegex: RegExp, replaceValue: string) => void;
    type FileFilterOptions = {
        nameBlacklist: string[];
        typeWhitelist?: string[];
    };
    const defaultFileFilterOptions: FileFilterOptions;
    const listAllFiles: (directory: string, options?: FileFilterOptions) => string[];
}
export declare const setActionTypes: (plop: NodePlopAPI) => void;
//# sourceMappingURL=fileSystem.d.ts.map