"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setActionTypes = exports.GeneratorActions = exports.GeneratorActionType = void 0;
const tslib_1 = require("tslib");
const generator_runner_1 = tslib_1.__importDefault(require("node-plop/lib/generator-runner"));
const utils_1 = require("../../utils");
var GeneratorActionType;
(function (GeneratorActionType) {
    GeneratorActionType["run"] = "Run generator";
})(GeneratorActionType = exports.GeneratorActionType || (exports.GeneratorActionType = {}));
const getGeneratorRunner = (plop, flags) => {
    const standardRunner = (0, generator_runner_1.default)(plop, flags);
    return Object.assign(Object.assign({}, standardRunner), { runGeneratorPrompts: (generator, bypass = [], prevAns = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const { prompts } = generator;
            if (prompts == null) {
                throw Error(`${generator.description} has no prompts`);
            }
            if (typeof prompts === 'function') {
                return prompts(plop['inquirer'], prevAns);
            }
            return standardRunner.runGeneratorPrompts(generator, bypass);
        }) });
};
var GeneratorActions;
(function (GeneratorActions) {
    GeneratorActions.run = (generator, prevAns, plop, bypass = [], flags = {}) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!generator) {
            throw new Error(`Invalid generator, unable to run.`);
        }
        const runner = getGeneratorRunner(plop, flags);
        const nextAns = yield runner.runGeneratorPrompts(generator, bypass, prevAns);
        utils_1.progressSpinner.start();
        const data = Object.assign(Object.assign({}, prevAns), nextAns);
        const outcome = yield runner.runGeneratorActions(generator, data, {
            onComment: (msg) => {
                utils_1.progressSpinner.info(msg);
                utils_1.progressSpinner.start();
            },
            onSuccess: (change) => {
                utils_1.progressSpinner.succeed(`${change.type} ${change.path}`);
                utils_1.progressSpinner.start();
            },
            onFailure: (failure) => {
                const errMsg = failure.error || failure.message;
                utils_1.progressSpinner.fail(`${failure.type} ${failure.path} ${errMsg}`);
                utils_1.progressSpinner.start();
            },
        });
        utils_1.progressSpinner.stop();
        return [data, outcome];
    });
})(GeneratorActions = exports.GeneratorActions || (exports.GeneratorActions = {}));
const setActionTypes = (plop) => {
    plop.setActionType(GeneratorActionType.run, (answers, config) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const outcome = yield GeneratorActions.run(config.generator, answers, plop, config.bypass);
        return '';
    }));
};
exports.setActionTypes = setActionTypes;
