"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setActionTypes = exports.GitActions = exports.GitActionType = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const simple_git_1 = tslib_1.__importDefault(require("simple-git"));
const utils_1 = require("../../utils");
var GitActionType;
(function (GitActionType) {
    GitActionType["clone"] = "Clone git repository";
})(GitActionType = exports.GitActionType || (exports.GitActionType = {}));
var GitActions;
(function (GitActions) {
    GitActions.clone = (directory, seed) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!(0, utils_1.directoryExists)(directory)) {
            throw new Error(`Target directory does not exist: ${directory}`);
        }
        if ((0, utils_1.directoryExists)(path_1.default.join(directory, '.git'))) {
            throw new Error(`A git repository already exists in: ${directory}`);
        }
        if (!seed) {
            throw new Error(`Invalid seed information, unable to clone. Seed: ${seed}`);
        }
        const { remoteUser, remoteName, remoteRepo, remoteBranch, gitOptions } = seed;
        const fullyQualifiedRemoteRepo = `git@github.com:${remoteUser}/${remoteRepo}.git`;
        const options = {
            baseDir: directory,
            binary: 'git',
            maxConcurrentProcesses: 6,
        };
        const git = (0, simple_git_1.default)(options);
        yield git.init();
        yield git.addRemote(remoteName, fullyQualifiedRemoteRepo);
        yield git.pull(remoteName, remoteBranch, gitOptions);
    });
})(GitActions = exports.GitActions || (exports.GitActions = {}));
const setActionTypes = (plop) => {
    plop.setActionType(GitActionType.clone, (answers, config) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const { directory, seed } = config;
        yield GitActions.clone(directory, seed);
        return '';
    }));
};
exports.setActionTypes = setActionTypes;
