"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genxHelpScreen = exports.helpScreen = exports.appHelpScreen = void 0;
const task_runtime_1 = require("../../task-runtime");
const color_1 = require("./color");
const format_1 = require("./format");
const cliKey = (value) => `$ ${color_1.CLI.key(value)}`;
const cliSectionHeader = (title, note) => `${format_1.Format.strong(`${title}:`)} ${color_1.CLI.note(note)}`;
const workspaceHelp = (config) => {
    const key = `${cliKey(config.binCmdKey)}`;
    return `
${cliSectionHeader('Workspaces', 'Workspaces are top level client monorepos.')}

  ${key} ${color_1.CLI.command(`workspace`)} ${color_1.CLI.subCommand(`create`)} ${color_1.CLI.note('Create a workspace')}
  ${key} ${color_1.CLI.command(`workspace`)} ${color_1.CLI.subCommand(`delete`)} ${color_1.CLI.note('Delete a workspace')}
  ${key} ${color_1.CLI.command(`workspace`)} ${color_1.CLI.subCommand(`list`)} ${color_1.CLI.note('List workspaces')}
  ${key} ${color_1.CLI.command(`workspace`)} ${color_1.CLI.subCommand(`configure`)} ${color_1.CLI.note('Configure an existing workspace')}
`;
};
const appHelpScreen = (config, tasks) => {
    const key = `${cliKey(config.binCmdKey)}`;
    const taskList = tasks
        .map((task) => `  ${key} ${color_1.CLI.command(`app`)} ${color_1.CLI.subCommand(task.name)} ${color_1.CLI.note(task.description)}`)
        .join('\n');
    console.log(`
  ${cliKey(config.binCmdKey)} ${color_1.CLI.command(`app`)} ${color_1.CLI.subCommand('<task>')}

${cliSectionHeader('Apps', 'Apps are seed instances. Tasks are commands provided by a seed.')}

  ${key} ${color_1.CLI.command(`app`)} ${color_1.CLI.note('List all tasks')}
${taskList}
  `);
};
exports.appHelpScreen = appHelpScreen;
const helpScreen = (config) => {
    const runtime = (0, task_runtime_1.getRuntime)();
    console.log(`
  ${cliKey(config.binCmdKey)} ${color_1.CLI.command(`<command>`)} ${color_1.CLI.subCommand('<subcommand>')}
  `);
    (0, exports.appHelpScreen)(config, runtime.tasks);
};
exports.helpScreen = helpScreen;
const genxHelpScreen = () => {
    console.log([
        '',
        `${cliSectionHeader('Usage', 'Workspaces are top level client monorepos.')}`,
        '  $ plop                 ' + color_1.CLI.note('Select from a list of available generators'),
        '  $ plop <name>          ' + color_1.CLI.note('Run a generator registered under that name'),
        '  $ plop <name> [input]  ' + color_1.CLI.note('Run the generator with input data to bypass prompts'),
        '',
        color_1.Text.bold('Options:'),
        '  -h, --help             ' + color_1.CLI.note('Show this help display'),
        '  -t, --show-type-names  ' + color_1.CLI.note('Show type names instead of abbreviations'),
        '  -i, --init             ' + color_1.CLI.note('Generate a basic plopfile.js'),
        '  -v, --version          ' + color_1.CLI.note('Print current version'),
        '  -f, --force            ' + color_1.CLI.note('Run the generator forcefully'),
        '',
        color_1.CLI.note(' ------------------------------------------------------'),
        color_1.CLI.note('  ⚠  danger waits for those who venture below the line'),
        '',
        color_1.CLI.note('  --plopfile             Path to the plopfile'),
        color_1.CLI.note('  --cwd                  Directory from which relative paths are calculated against while locating the plopfile'),
        color_1.CLI.note('  --require              String or array of modules to require before running plop'),
        color_1.CLI.note("  --dest                 Output to this directory instead of the plopfile's parent directory"),
        '',
        color_1.Text.bold('Examples:'),
        '  $ ' + color_1.CLI.key('plop'),
        '  $ ' + color_1.CLI.key('plop component'),
        '  $ ' + color_1.CLI.key('plop component "name of component"'),
        '',
    ].join('\n'));
};
exports.genxHelpScreen = genxHelpScreen;
