"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractSeed = exports.downloadSeed = exports.downloadSeedList = void 0;
const tslib_1 = require("tslib");
const node_stream_1 = require("node:stream");
const node_util_1 = require("node:util");
const node_zlib_1 = tslib_1.__importDefault(require("node:zlib"));
const tar = tslib_1.__importStar(require("tar"));
const store_1 = require("../../store");
const utils_1 = require("../../utils");
const normalizers_1 = require("../normalizers");
const downloadSeedList = (type = 'apps', binCmdKey = store_1.configStore.values.binCmdKey, authToken = store_1.configStore.values.jfrog.token, authTokenType = store_1.configStore.values.jfrog.tokenType) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const response = yield (0, utils_1.downloadJson)(`https://genesisglobal.jfrog.io/artifactory/seed-area/${type}.${binCmdKey}.json`, authToken, authTokenType);
    if (!response.ok) {
        throw (0, utils_1.responseNotOk)(response, 'Unable to download seeds information');
    }
    const data = yield response.json();
    return (0, normalizers_1.seedNormalizer)(data.seeds);
});
exports.downloadSeedList = downloadSeedList;
const downloadSeed = (seed, authToken = store_1.configStore.values.jfrog.token, authTokenType = store_1.configStore.values.jfrog.tokenType) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { vcsUrl, vcsOperation, vcsRemote, remoteUser, remoteRepo, remoteBranch } = seed;
    const response = yield (0, utils_1.downloadBinary)(`${vcsUrl}/${vcsOperation}/${vcsRemote}/${remoteUser}/${remoteRepo}/${remoteBranch}`, authToken, authTokenType);
    if (!response.ok) {
        throw (0, utils_1.responseNotOk)(response, 'Unable to download seed');
    }
    return response;
});
exports.downloadSeed = downloadSeed;
const extractSeed = (seed, stream, directory) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if (!(0, utils_1.directoryExists)(directory)) {
        throw new Error(`Extract directory does not exist: ${directory}`);
    }
    const extractOptions = {
        cwd: directory,
        strip: 1,
    };
    const streamPipeline = (0, node_util_1.promisify)(node_stream_1.pipeline);
    yield streamPipeline(stream, node_zlib_1.default.createUnzip(), tar.x(extractOptions));
});
exports.extractSeed = extractSeed;
