"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runMigration = exports.workspaceSchemaMigration = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const semver_1 = tslib_1.__importDefault(require("semver"));
exports.workspaceSchemaMigration = [
    {
        version: '^1.0.0',
        transform: (input) => ({
            version: '^1.0.0',
            type: input.type,
            value: `${input.value} World`,
        }),
    },
    {
        version: '^2.0.0',
        transform: (input) => ({
            version: '^2.0.0',
            type: input.type,
            value: `${input.value} Tour`,
        }),
    },
];
const stringifySpace = 2;
const runMigration = (schema, schemaMigration) => {
    const nextStepIndex = schemaMigration.findIndex((step) => {
        return semver_1.default.gtr(semver_1.default.coerce(step.version), schema.version);
    });
    if (nextStepIndex === -1 || nextStepIndex >= schemaMigration.length) {
        console.info(`
${chalk_1.default.green(`Schema ${chalk_1.default.bold(schema.version)} is up-to-date`)}
    `);
        return schema;
    }
    const steps = schemaMigration.slice(nextStepIndex);
    const resultingSchema = steps.reduce((acc, currentStep) => currentStep.transform(acc), schema);
    console.info(`
${chalk_1.default.green(`Migrated Schema: ${chalk_1.default.bold(schema.type)}`)}

${chalk_1.default.bgYellow(chalk_1.default.black(`from:`))}
${chalk_1.default.yellow(JSON.stringify(schema, null, stringifySpace))}

${chalk_1.default.bgYellow(chalk_1.default.black(`to:`))}
${chalk_1.default.green(JSON.stringify(resultingSchema, null, stringifySpace))}

`);
    return resultingSchema;
};
exports.runMigration = runMigration;
