"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configStore = exports.encryptionKey = void 0;
const tslib_1 = require("tslib");
const conf_1 = tslib_1.__importDefault(require("conf"));
const { version: pkgVersion } = require('../../package.json');
exports.encryptionKey = 'publicSeedsPleaseGenesis';
const keys = {
    external: `external`,
    binCmdKey: `binCmdKey`,
    version: `version`,
    jfrogUsername: `jfrog.username`,
    jfrogToken: `jfrog.token`,
    jfrogTokenExpiry: `jfrog.tokenExpiry`,
    jfrogTokenType: `jfrog.tokenType`,
};
const schema = {
    external: {
        type: 'boolean',
        default: true,
    },
    binCmdKey: {
        type: 'string',
        enum: ['genx', 'foundation-cli'],
        default: 'genx',
    },
    version: {
        type: 'string',
        default: pkgVersion,
    },
    jfrog: {
        type: 'object',
        properties: {
            username: {
                type: 'string',
            },
            token: {
                type: 'string',
            },
            tokenExpiry: {
                type: 'string',
            },
            tokenType: {
                type: 'string',
                enum: ['Bearer', 'Basic'],
            },
        },
    },
};
const conf = new conf_1.default({ schema, encryptionKey: exports.encryptionKey });
exports.configStore = {
    keys,
    values: {
        get external() {
            return conf.get(keys.external);
        },
        get binCmdKey() {
            return conf.get(keys.binCmdKey);
        },
        get version() {
            return conf.get(keys.version);
        },
        jfrog: {
            get username() {
                return conf.get(keys.jfrogUsername);
            },
            get token() {
                return conf.get(keys.jfrogToken);
            },
            get tokenExpiry() {
                return conf.get(keys.jfrogTokenExpiry);
            },
            get tokenType() {
                return conf.get(keys.jfrogTokenType);
            },
            clearToken() {
                conf.delete(keys.jfrogToken);
                conf.delete(keys.jfrogTokenExpiry);
                conf.delete(keys.jfrogTokenType);
            },
        },
    },
    getValue: (key) => conf.get(key),
    setValue: (key, value) => conf.set(key, value),
    deleteValue: (key) => conf.delete(key),
};
