/// <reference types="node" />
import { SpawnOptions } from 'child_process';
import { Answers } from 'inquirer';
import { PlopGeneratorConfig } from 'node-plop';
export interface PlopActionHooksFailures {
    type: string;
    path: string;
    error: string;
    message: string;
}
export interface PlopActionHooksChanges {
    type: string;
    path: string;
}
export interface PlopActionHooks {
    onComment?: (msg: string) => void;
    onSuccess?: (change: PlopActionHooksChanges) => void;
    onFailure?: (failure: PlopActionHooksFailures) => void;
}
export interface GeneratorActionsOutcome {
    changes: PlopActionHooksChanges[];
    failures: PlopActionHooksFailures[];
}
export interface PlopGeneratorRunner {
    runGeneratorPrompts: (generator: PlopGeneratorConfig, bypassArr?: string[], prevAns?: Answers) => Promise<any>;
    runGeneratorActions: (generator: PlopGeneratorConfig, data: any, hooks?: PlopActionHooks) => Promise<GeneratorActionsOutcome>;
}
export declare enum Entitlement {
    workspaceCreate = "Workspace_Create",
    workspaceConfigure = "Workspace_Configure",
    workspaceDelete = "Workspace_Delete",
    workspaceList = "Workspace_List",
    appCreate = "App_Create",
    appConfigure = "App_Configure",
    appDelete = "App_Delete",
    appList = "App_List",
    foundationSync = "Foundation_Sync",
    foundationSchemaCreate = "Foundation_Schema_Create",
    foundationComponentCreate = "Foundation_Component_Create",
    designSystemCreate = "Design_System_Create"
}
export type BinCmdKey = 'genx' | 'foundation-cli';
export type TokenType = 'Bearer' | 'Basic';
export type SeedListType = 'apps' | 'workspaces';
export type ContentType = 'application/octet-stream' | 'application/json' | 'application/x-www-form-urlencoded';
export interface RunConfig {
    external: boolean;
    binCmdKey: BinCmdKey;
}
export interface HelpConfig {
    binCmdKey: BinCmdKey;
}
export declare const DslTag = "DSL";
export declare const dslName = "GPALX";
export declare const GENX_DIR = ".genx";
export declare const appCommand = "app";
export interface ShellOptions {
    readonly command: string;
    readonly cwd?: string;
    readonly label?: string;
    readonly logprefix?: string;
    readonly spawnOptions?: SpawnOptions;
    readonly quiet?: boolean;
}
export interface TaskStep {
    readonly name?: string;
    readonly cwd?: string;
    readonly exec?: string;
    readonly spawn?: string;
    readonly say?: string;
    readonly builtin?: string;
}
export interface TaskSpec {
    readonly name: string;
    readonly steps?: TaskStep[];
    readonly description?: string;
    readonly env?: {
        [name: string]: string;
    };
    readonly requiredEnv?: string[];
    readonly condition?: string;
    readonly cwd?: string;
}
export interface TasksManifest {
    readonly tasks?: {
        [name: string]: TaskSpec;
    };
    readonly env?: {
        [name: string]: string;
    };
}
//# sourceMappingURL=types.d.ts.map